/*
 * Make directories in a filesystem.
 *
 * Copyright (C) 2019, 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <stdio.h>

#include <ext2fs/ext2fs.h>

#include "image.h"
#include "session.h"



/* Alternative metadata set by options. */

extern struct metadata md;



/* Make directories in the filesystem image. */

int make_dirs(ext2_filsys fs, int argc, char *argv[])
{
    int i;
    const char *path;
    ext2_ino_t ino;

    /* Make each directory component in the given pathname. */

    for (i = 0; i < argc; i++)
    {
        path = argv[i];

        /* Search for the remaining components. */

        if ((!*path) || !image_resolve_by_path(fs, &path, &ino))
        {
            fprintf(stderr, "Path exists: %s\n", argv[i]);
            return 1;
        }

        /* From the first unrecognised component, make the remaining
           directories. */

        if (image_make_dirs(fs, &path, ino,
                            0777 & ~md.mask,
                            md.have_uid ? md.uid : 0,
                            md.have_gid ? md.gid : 0))
        {
            fprintf(stderr, "Failed to make directory: %s\n", argv[i]);
            return 1;
        }
    }

    return 0;
}

/* vim: tabstop=4 expandtab shiftwidth=4
*/
